function [AUC ROC]=auc_roc_ncssvm(xt,yt,xs,ys,hkernel,kernelparam,gamma,alpha,alpha0)
if nargin<9
    alpha0=0;
end
if (length(alpha0)<size(alpha,2))
	alpha0=zeros(size(alpha,2),1);
end

[Nt M] = size(alpha);

% test
Ns = size(xs,1);
Ns0 = sum(ys==-1);
Ns1 = sum(ys== 1);
Ks = hkernel(xs,xt,kernelparam);
gs = Ks*(alpha.*repmat(yt,1,M)) + repmat(alpha0',Ns,1);

% interpolation
gamma1 = zeros(Ns,1);
gii = 1;
for ii=1:M-1
%     idx = find(gs(:,ii)<0 & gs(:,ii+1)>=0);
    idx = (gs(:,ii)<0 & gs(:,ii+1)>=0);
    idx = idx & (ys==-1);
    gam = (gamma(ii+1)*gs(idx,ii)-gamma(ii)*gs(idx,ii+1))./(gs(idx,ii)-gs(idx,ii+1));
    gam = gam(gam>=gamma(ii) & gam<=gamma(ii+1));
    gamma1(gii:gii+length(gam)-1)=gam;
    gii = gii+length(gam);
end
gamma1 = gamma1(1:gii-1);
gamma1 = sort(unique(gamma1), 'ascend');

% interpolation
gs1 = interp1(gamma, gs', gamma1);  % for memory save, no transpose

% threshold
[tha, thi] = min(abs(gs1),[],2);
th = gs1(sub2ind(size(gs1), (1:length(thi))', thi));

% roc & auc
ROC = [sum(gs(ys==-1,1)>=0,1)   sum(gs(ys== 1,1)>=0,1); ...
       sum(gs1(:,ys==-1) > repmat(th,1,Ns0),2)  sum(gs1(:,ys== 1) >  repmat(th,1,Ns1),2); ...
       sum(gs(ys==-1,end)>=0,1) sum(gs(ys== 1,end)>=0,1)];

AUC = sum(diff(ROC(:,1)).*ROC(1:end-1,2))/(Ns0*Ns1);
% AUC = trapz(ROC(:,1), ROC(:,2))/(Ns0*Ns1);

% error check
if sum(ROC~=sortrows(ROC))
    fprintf('WARNING: auc_roc_ncssvm.m \t ROC not monotone \n');
end
if (ROC(1,1)>0 || ROC(end,1)<Ns0)
    fprintf('WARNING: auc_roc_ncssvm.m \t test set \n');
end
