% Nested Support Vector Machines
% NCS-SVM demo
% 
% Gyemin Lee, University of Michigan
% 2009.5.17
% 
clear
home

datastr = 'banana';
dataidx = '1';

% 
% NCS-SVM test
% 
% training data set
[xt yt] = util_rdbenchdata(datastr, dataidx, 'train');

% kernel bandwidth
ncs_sigma = 0.5;

% regularization parameter
ncs_lambdamax = cssvm_lambdamax(xt, yt, @knl_radial, ncs_sigma);
ncs_lambda = ncs_lambdamax*0.7;

% breakpoints 
ncs_gammanum = 5;
ncs_gamma = linspace(0,1,ncs_gammanum)';

% train NCS-SVM
[ncs_alpha, ncs_ff, ncs_dual] = ncssvm_wb(xt, yt, @knl_radial, ncs_sigma, ncs_lambda, ncs_gamma);

% plot decision boudaries
figure(2)
plot_cssvm_set(xt,yt,@knl_radial,ncs_sigma,ncs_lambda,ncs_alpha);


% test
[xs ys] = util_rdbenchdata(datastr, dataidx, 'test');
Ns0 = sum(ys==-1);
Ns1 = sum(ys== 1);

[ncs_auc, ncs_roc] = auc_roc_ncssvm(xt,yt,xs,ys,@knl_radial,ncs_sigma,ncs_gamma,ncs_alpha);

figure(3)
plot(ncs_roc(:,1)/Ns0, ncs_roc(:,2)/Ns1)
xlabel('False negative'), ylabel('True positive')
title(['AUC : ' num2str(ncs_auc)])
